@@ -1,11 +1,11 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/prj/pg/ipa-pgpool2/cvsroot/ipa-pgpool2/pgpool_src/child.c,v 1.36 2006/07/30 14:31:16 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool-II/child.c,v 1.4 2007/02/12 02:32:08 y-asaba Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2006	PgPool Global Development Group
+ * Copyright (c) 2003-2007	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -248,14 +248,14 @@ void do_child(int unix_fd, int inet_fd)
 
 		/* look for existing connection */
 		found = 0;
-		backend = pool_get_cp(sp->user, sp->database, sp->major);
+		backend = pool_get_cp(sp->user, sp->database, sp->major, 1);
 
 		if (backend != NULL)
 		{
 			found = 1;
 
 			/* existing connection associated with same user/database/major found.
-			 * however we should make sure that the startup packet contents identical.
+			 * however we should make sure that the startup packet contents are identical.
 			 * OPTION data and others might be different.
 			 */
 			if (sp->len != MASTER_CONNECTION(backend)->sp->len)
