@@ -1,11 +1,11 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool-II/parser/pool_memory.c,v 1.1.1.1 2006/09/08 03:36:42 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool-II/parser/pool_memory.c,v 1.5 2007/01/04 17:27:11 devrim Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2006	PgPool Global Development Group
+ * Copyright (c) 2003-2007	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -61,7 +61,7 @@ void *pool_memory_alloc(POOL_MEMORY_POOL *pool, unsigned int size)
 	POOL_BLOCK *block;
 	POOL_CHUNK *chunk;
 
-	if (size > MAX_SIZE)
+	if ((size + POOL_HEADER_SIZE) > MAX_SIZE)
 	{
 		block = malloc(sizeof(POOL_BLOCK));
 		if (block == NULL)
@@ -150,16 +150,25 @@ void pool_memory_free(POOL_MEMORY_POOL *pool, void *ptr)
 	POOL_CHUNK *chunk = ptr - POOL_HEADER_SIZE;
 	int fidx;
 
+	if (ptr == NULL)
+		return;
+
 	if (chunk->header.size > MAX_SIZE)
 	{
 		POOL_BLOCK *block, *ptr = NULL;
 
-		for (block = pool->largeblocks; block; ptr = block)
+		for (block = pool->largeblocks; block; ptr = block, block = block->next)
 		{
 			if (block->block == chunk)
 				break;
 		}
 
+		if (block == NULL)
+		{
+			pool_log("An adress \"%p\" does not exist in memory pool.", chunk);
+			return;
+		}
+
 		if (ptr == NULL)
 		{
 			pool->largeblocks = block->next;
