@@ -1,11 +1,11 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool-II/pool_connection_pool.c,v 1.1.1.1 2006/09/08 03:36:08 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool-II/pool_connection_pool.c,v 1.4 2007/02/12 02:32:08 y-asaba Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2006	PgPool Global Development Group
+ * Copyright (c) 2003-2007	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -44,6 +44,7 @@ POOL_CONNECTION_POOL *pool_connection_pool;	/* connection pool */
 
 static POOL_CONNECTION_POOL_SLOT *create_cp(POOL_CONNECTION_POOL_SLOT *cp, int slot);
 static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p);
+static int check_socket_status(int fd);
 
 /*
 * initialize connection pools. this should be called once at the startup.
@@ -71,7 +72,7 @@ int pool_init_cp(void)
 /*
 * find connection by user and database
 */
-POOL_CONNECTION_POOL *pool_get_cp(char *user, char *database, int protoMajor)
+POOL_CONNECTION_POOL *pool_get_cp(char *user, char *database, int protoMajor, int check_socket)
 {
 #ifdef HAVE_SIGPROCMASK
 	sigset_t oldmask;
@@ -79,7 +80,8 @@ POOL_CONNECTION_POOL *pool_get_cp(char *user, char *database, int protoMajor)
 	int	oldmask;
 #endif
 
-	int i;
+	int i, j, freed = 0;
+	ConnectionInfo *info;
 
 	POOL_CONNECTION_POOL *p = pool_connection_pool;
 
@@ -99,10 +101,48 @@ POOL_CONNECTION_POOL *pool_get_cp(char *user, char *database, int protoMajor)
 			strcmp(MASTER_CONNECTION(p)->sp->user, user) == 0 &&
 			strcmp(MASTER_CONNECTION(p)->sp->database, database) == 0)
 		{
+			int sock_broken = 0;
+
 			/* mark this connection is under use */
 			MASTER_CONNECTION(p)->closetime = 0;
 			p->info->counter++;
 			POOL_SETMASK(&oldmask);
+
+			if (check_socket)
+			{
+				for (j=0;j<NUM_BACKENDS;j++)
+				{
+					if (!VALID_BACKEND(j))
+						continue;
+
+					sock_broken = check_socket_status(CONNECTION(p, j)->fd);
+					if (sock_broken < 0)
+						break;
+				}
+
+				if (sock_broken < 0)
+				{
+					pool_log("connection closed. retry to create new connection pool.");
+					for (j=0;j<NUM_BACKENDS;j++)
+					{
+						if (!VALID_BACKEND(j))
+							continue;
+
+						if (!freed)
+						{
+							pool_free_startup_packet(CONNECTION_SLOT(p, j)->sp);
+							freed = 1;
+						}
+				
+						pool_close(CONNECTION(p, j));
+					}
+					info = p->info;
+					memset(p, 0, sizeof(POOL_CONNECTION_POOL));
+					p->info = info;
+					memset(p->info, 0, sizeof(ConnectionInfo));
+					return NULL;
+				}
+			}
 			return p;
 		}
 		p++;
@@ -117,7 +157,7 @@ POOL_CONNECTION_POOL *pool_get_cp(char *user, char *database, int protoMajor)
  */
 void pool_discard_cp(char *user, char *database, int protoMajor)
 {
-	POOL_CONNECTION_POOL *p = pool_get_cp(user, database, protoMajor);
+	POOL_CONNECTION_POOL *p = pool_get_cp(user, database, protoMajor, 0);
 	ConnectionInfo *info;
 	int i, freed = 0;
 
@@ -530,3 +570,34 @@ static POOL_CONNECTION_POOL *new_connection(POOL_CONNECTION_POOL *p)
 
 	return NULL;
 }
+
+/* check_socket_status()
+ * RETURN: 0 => OK
+ *        -1 => broken socket.
+ */
+static int check_socket_status(int fd)
+{
+	fd_set rfds;
+	int result;
+	struct timeval t;
+
+	for (;;)
+	{
+		FD_ZERO(&rfds);
+		FD_SET(fd, &rfds);
+
+		t.tv_sec = t.tv_usec = 0;
+
+		result = select(fd+1, &rfds, NULL, NULL, &t);
+		if (result < 0 && errno == EINTR)
+		{
+			continue;
+		}
+		else
+		{
+			return (result == 0 ? 0 : -1);
+		}
+	}
+
+	return -1;
+}
